#!/usr/bin/python3

import cv2
import sys

from phycam import PhyCam

def main(args):
    cam = PhyCam()

    cam.select_mode("HD")
    cam.setup_pipeline()
    cam.set_controls()

    cap = cv2.VideoCapture(cam.gst_pipeline, cv2.CAP_GSTREAMER)

    if not cap.isOpened():
        raise RuntimeError("Cannot open camera")

    cv2.namedWindow('phyCAM - LiveView', cv2.WND_PROP_FULLSCREEN)
    cv2.setWindowProperty('phyCAM - LiveView',
                          cv2.WND_PROP_FULLSCREEN,
                          cv2.WINDOW_FULLSCREEN)

    while(True):
        ret, frame = cap.read()

        if cam.opencv_conv:
            frame = cv2.cvtColor(frame, cam.opencv_conv)

        cv2.imshow("phyCAM - LiveView", frame)

        key = cv2.waitKey(1)

        if key & 0xFF == ord("q"):
            break

    cv2.destroyAllWindows()
    cap.release()


if __name__ == '__main__':
    try:
        main(sys.argv)
    except KeyboardInterrupt:
        cv2.destroyAllWindows()
        sys.exit(0)
