#!/usr/bin/python3

import cv2
import sys

from phycam import PhyCam

def main(args):
    cam = PhyCam()

    cam.select_mode("HD")
    cam.setup_pipeline()
    cam.set_controls()

    cap = cv2.VideoCapture(cam.gst_pipeline, cv2.CAP_GSTREAMER)

    if not cap.isOpened():
        raise RuntimeError("Cannot open camera")

    cv2.namedWindow('phyCAM - FaceDetection', cv2.WND_PROP_FULLSCREEN)
    cv2.setWindowProperty('phyCAM - FaceDetection',
                          cv2.WND_PROP_FULLSCREEN,
                          cv2.WINDOW_FULLSCREEN)

    cascade = cv2.CascadeClassifier("haarcascade_frontalface_default.xml")
    nested = cv2.CascadeClassifier("haarcascade_eye.xml")

    color_green = (0, 255, 0)

    while(True):
        ret, frame = cap.read()

        if cam.opencv_conv:
            frame = cv2.cvtColor(frame, cam.opencv_conv)
            gray = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
        else:
            gray = frame

        faces = cascade.detectMultiScale(gray, scaleFactor=4, minNeighbors=3,
                                         minSize=(25, 25),
                                         flags=cv2.CASCADE_SCALE_IMAGE)

        if len(faces) != 0:
            for x1, y1, w, h in faces:
                cv2.rectangle(frame, (x1, y1), (x1+w, y1+w), color_green, 2)

        cv2.imshow("phyCAM - FaceDetection", frame)

        key = cv2.waitKey(1)

        if key & 0xFF == ord("q"):
            break

    cv2.destroyAllWindows()
    cap.release()


if __name__ == '__main__':
    try:
        main(sys.argv)
    except KeyboardInterrupt:
        cv2.destroyAllWindows()
        sys.exit(0)
