import cv2


ar0144_formats = {
    "color" : {
        "cam" : "SGRBG8_1X8",
        "opencv" : cv2.COLOR_BAYER_GB2BGR,
        "gst" : "video/x-bayer,format=grbg",
        "controls" : [
            "dynamic_defect_pixel_correction=1",
            "digital_gain_red=1300",
            "digital_gain_blue=1500",
            "digital_gain_green_red=1000",
            "digital_gain_green_blue=1000",
        ],
    },
    "monochrome" : {
        "cam" : "Y8_1X8",
        "opencv" : None,
        "gst" : "video/x-raw,format=GRAY8",
        "controls" : [
            "dynamic_defect_pixel_correction=1",
        ],
    },
}

ar0234_formats = {
    "color" : {
        "cam" : "SGRBG8_1X8",
        "opencv" : cv2.COLOR_BAYER_GB2BGR,
        "gst" : "video/x-bayer,format=grbg",
        "controls" : [
            "dynamic_defect_pixel_correction=1",
            "digital_gain_red=1300",
            "digital_gain_blue=1500",
            "digital_gain_green_red=1000",
            "digital_gain_green_blue=1000",
        ],
    },
    "monochrome" : {
        "cam" : "Y8_1X8",
        "opencv" : None,
        "gst" : "video/x-raw,format=GRAY8",
        "controls" : [
            "dynamic_defect_pixel_correction=1",
        ],
    },
}

ar0521_formats = {
    "color" : {
        "cam" : "SGRBG8_1X8",
        "opencv" : cv2.COLOR_BAYER_GB2BGR,
        "gst" : "video/x-bayer,format=grbg",
        "controls" : [
            "exposure=2240",
            "dynamic_defect_pixel_correction=1",
            "digital_gain_red=1400",
            "digital_gain_blue=1400",
            "digital_gain_green_red=1000",
            "digital_gain_green_blue=1000",
        ],
    },
    "monochrome" : {
        "cam" : "Y8_1X8",
        "opencv" : None,
        "gst" : "video/x-raw,format=GRAY8",
        "controls" : [
            "exposure=2240",
            "dynamic_defect_pixel_correction=1",
        ],
    },
}

ar0144_modes = {
    "Full" : {
        "name" : "1280x800 Full",
        "width" : 1280,
        "height" : 800,
        "offset" : "(0,4)",
        "cap_width" : 1280,
        "cap_height" : 800,
        "controls" : [
            "row_binning=0",
            "col_binning=0",
            "auto_exposure_max=800",
        ],
    },
    "HD" : {
        "name" : "1280x720 HD",
        "width" : 1280,
        "height" : 720,
        "offset" : "(0,44)",
        "cap_width" : 1280,
        "cap_height" : 720,
        "controls" : [
            "row_binning=0",
            "col_binning=0",
            "auto_exposure_max=720",
        ],
    },
    "VGA" : {
        "name" : "640x480 VGA",
        "width" : 640,
        "height" : 480,
        "offset" : "(320,164)",
        "cap_width" : 640,
        "cap_height" : 480,
        "controls" : [
            "row_binning=0",
            "col_binning=0",
            "auto_exposure_max=480",
        ],
    },
}

ar0234_modes = {
    "Full" : {
        "name" : "1920x1200 Full",
        "width" : 1920,
        "height" : 1200,
        "offset" : "(8,8)",
        "cap_width" : 1920,
        "cap_height" : 1200,
        "controls" : [
            "row_binning=0",
            "col_binning=0",
            "auto_exposure_max=1200",
        ],
    },
    "FullHD" : {
        "name" : "1920x1080 FullHD",
        "width" : 1920,
        "height" : 1080,
        "offset" : "(8,68)",
        "cap_width" : 1920,
        "cap_height" : 1080,
        "controls" : [
            "row_binning=0",
            "col_binning=0",
            "auto_exposure_max=1080",
        ],
    },
    "HD" : {
        "name" : "1280x720 HD",
        "width" : 1280,
        "height" : 720,
        "offset" : "(328,248)",
        "cap_width" : 1280,
        "cap_height" : 720,
        "controls" : [
            "row_binning=0",
            "col_binning=0",
            "auto_exposure_max=720",
        ],
    },
    "SVGA" : {
        "name" : "800x600 SVGA",
        "width" : 1600,
        "height" : 1200,
        "offset" : "(168,8)",
        "cap_width" : 800,
        "cap_height" : 600,
        "controls" : [
            "row_binning=1",
            "col_binning=1",
            "auto_exposure_max=600",
        ],
    },
}

ar0521_modes = {
    "Full" : {
        "name" : "2592x1944 Full",
        "width" : 2592,
        "height" : 1944,
        "offset" : "(4,4)",
        "cap_width" : 2592,
        "cap_height" : 1944,
        "controls" : [
            "column_binning=0",
        ],
    },
    "FullHD" : {
        "name" : "1920x1080 FullHD",
        "width" : 1920,
        "height" : 1080,
        "offset" : "(336,432)",
        "cap_width" : 1920,
        "cap_height" : 1080,
        "controls" : [
            "column_binning=0",
        ],
    },
    "HD" : {
        "name" : "1280x720 HD",
        "width" : 2560,
        "height" : 1440,
        "offset" : "(16,252)",
        "cap_width" : 1280,
        "cap_height" : 720,
        "controls" : [
            "column_binning=1",
        ],
    },
    "VGA" : {
        "name" : "640x480 VGA",
        "width" : 2560,
        "height" : 1920,
        "offset" : "(16,12)",
        "cap_width" : 640,
        "cap_height" : 480,
        "controls" : [
            "column_binning=1",
        ],
    },
}
